@@ -1,14 +1,16 @@
 //! This library implements core components of Nova.
 #![allow(non_snake_case)]
 #![allow(clippy::type_complexity)]
-#![feature(test)]
 #![deny(missing_docs)]
 
 mod commitments;
 
 pub mod bellperson;
+mod circuit;
 pub mod errors;
+mod gadgets;
 pub mod pasta;
+mod poseidon;
 pub mod r1cs;
 pub mod traits;
 
